import pandas as pd
import pyarrow.parquet as pq
import glob
import numpy as np
import os

from sklearn.model_selection import cross_val_score
from sklearn.model_selection import RepeatedKFold
from sklearn.linear_model import Lasso

desired_width = 320
pd.set_option('display.width', desired_width)
pd.set_option('display.max_columns', 10)

#Loading the datasets
#Loading all unemployment files
filesUnemployment = glob.glob('unemployment_data_us/adjusted/*')
filesUnemployment.sort()

#Loading all US states files
files = glob.glob('../data_bg_us_v1/us/*/*.parquet')
files.sort()

#Concatting massively
df = pd.DataFrame()
for file in files:
    tempDf = pd.read_parquet(file, columns=['CanonState', 'JobDate', 'MaxAnnualSalary'])
    isTrue = filter(None, tempDf['MaxAnnualSalary'])
    tempDf['MaxAnnualSalary'] = pd.to_numeric(tempDf['MaxAnnualSalary'], errors='coerce')
    isTrue = tempDf.replace(to_replace='None', value=np.nan).dropna()
    df = pd.concat([df, isTrue])
#Making sure date is of date type
df['JobDate']=pd.to_datetime(df['JobDate'])
groupedDf=df.groupby(['CanonState', pd.Grouper(key='JobDate', freq='m')]).sum().reset_index()

df2 = pd.DataFrame()
for file in files:
    tempDf = pd.read_parquet(file, columns=['CanonState', 'JobDate', 'MinAnnualSalary'])
    isTrue = filter(None, tempDf['MinAnnualSalary'])
    tempDf['MinAnnualSalary'] = pd.to_numeric(tempDf['MinAnnualSalary'], errors='coerce')
    # != str
    isTrue = tempDf.replace(to_replace='None', value=np.nan).dropna()
    df2 = pd.concat([df2, isTrue])
#Making sure date is of date type
df2['JobDate']=pd.to_datetime(df['JobDate'])
groupedDf2=df2.groupby(['CanonState', pd.Grouper(key='JobDate', freq='m')]).sum().reset_index()
groupedDf['MinAnnualSalary'] = groupedDf2['MinAnnualSalary']
groupedDf['SumSalary'] = groupedDf['MaxAnnualSalary']+groupedDf['MinAnnualSalary']
groupedDf.to_parquet('total_grouped_max_min_annual_salaries.parquet')